@@ -201,8 +201,10 @@ pub trait VecVecu8 {
 
     /// Centroid = euclidian mean of a set of points  
     fn acentroid(self) -> Vec<f64>; 
-    fn nmedian(self, eps:f64) -> Vec<f64>;
-    fn betterpoint(self, v: &[f64]) -> (f64, Vec<f64>);
+    /// Eccentricity vector for a non member point. 
+    fn eccnonmember(self, p:&[f64]) -> Vec<f64>;
+    /// Geometric median of a set of nD points
+    fn gmedian(self, eps:f64) -> Vec<f64>;  
 
 }
 
@@ -246,14 +248,10 @@ pub trait VecVec {
 
     /// First iteration point for geometric medians
     fn firstpoint(self) -> Vec<f64>;
-
     /// Improved Weizsfeld's Algorithm for geometric median
     fn nmedian(self, eps: f64) -> Vec<f64>;
-    /// Vector iterative two point method for geometric median
-    fn gmedian(self, eps: f64) -> Vec<f64>;
-    /// Secant nethod for geometric median
-    fn smedian(self, eps: f64) -> Vec<f64>;
- 
+    /// New secant algorithm for geometric median
+    fn gmedian(self, eps: f64) -> Vec<f64>; 
 }
 
 /// Methods to manipulate indices of Vec<usize> type
