@@ -41,8 +41,8 @@ impl VecVec for &[Vec<f64>] {
     /// This is a robust relationship between two unordered multidimensional sets.
     /// The two sets have to be in the same space but can have different numbers of points.
     fn trend(self, eps: f64, v: Vec<Vec<f64>>) -> Vec<f64> {
-        let m1 = self.smedian(eps);
-        let m2 = v.smedian(eps);
+        let m1 = self.gmedian(eps);
+        let m2 = v.gmedian(eps);
         m2.vsub(&m1)
     }
 
@@ -133,18 +133,20 @@ impl VecVec for &[Vec<f64>] {
             let thisp = &self[i];
             for j in 0..i { 
                 // calculate each unit vector between any pair of points just once
-                let dv = self[j].vsub(&thisp);
-                let dvmag = dv.vmag();
+                let dvmag = self[j].vdist(&thisp);             
                 if !dvmag.is_normal() { continue }
                 let rec = 1.0/dvmag;
-                eccs[i].mutvadd(&dv.smult(rec));
+                eccs[i].mutvadd(&self[j].smult(rec));
                 recips[i] += rec;
                 // mind the vector's opposite orientations w.r.t. to the two points!
-                eccs[j].mutvsub(&dv.smult(rec)); 
+                eccs[j].mutvsub(&self[j].smult(rec)); 
                 recips[j] += rec;
             }
         }
-        for i in 0..n { eccs[i].mutsmult(1.0/recips[i])}
+        for i in 0..n { 
+            eccs[i].mutsmult(1.0/recips[i]); 
+            eccs[i].mutvsub(&self[i]) 
+        }
         eccs
     }
 
@@ -152,7 +154,7 @@ impl VecVec for &[Vec<f64>] {
     /// `not being the geometric median` for a member point.
     /// The true geometric median is as yet unknown.
     /// The true geometric median would return zero.
-    /// The member point iin question is specified by its index `indx`.
+    /// The member point in question is specified by its index `indx`.
     /// This function is suitable for a single member point. 
     /// When eccentricities of all the points are needed, use `eccentricities` above.
     fn eccmember(self, indx: usize) -> Vec<f64> {
@@ -162,15 +164,14 @@ impl VecVec for &[Vec<f64>] {
         let mut recip = 0_f64;
         for i in 0..n {
             if i == indx { continue  }; // exclude this point
-            let dv = self[i].vsub(&thisp);
-            let dvmag = dv.vmag();
-            if !dvmag.is_normal() { continue }
+            let dvmag = self[i].vdist(&thisp);
+            if !dvmag.is_normal() { continue } // too close to this one
             let rec = 1.0/dvmag;
-            vsum.mutvadd(&dv.smult(rec)); // add unit vector
+            vsum.mutvadd(&self[i].smult(rec)); // add unit vector
             recip += rec // add separately the reciprocals
         }
         vsum.mutsmult(1.0/recip);
-        vsum
+        vsum.vsub(&thisp)
     }
 
     /// Eccentricity vector for a non member point,
@@ -182,15 +183,14 @@ impl VecVec for &[Vec<f64>] {
         let mut vsum = vec![0_f64; self[0].len()];
         let mut recip = 0_f64;
         for x in self { 
-            let dv = x.vsub(&p);
-            let dvmag = dv.vmag();
-            if !dvmag.is_normal() { continue }
+            let dvmag = x.vdist(&p);
+            if !dvmag.is_normal() { continue } // zero distance, safe to ignore
             let rec = 1.0/dvmag;
-            vsum.mutvadd(&dv.smult(rec)); // add unit vector
+            vsum.mutvadd(&x.smult(rec)); // add unit vector
             recip += rec // add separately the reciprocals    
         }
         vsum.mutsmult(1.0/recip);
-        vsum
+        vsum.vsub(&p)
     }  
 
     /// Magnitudes of all the vectors in self
@@ -223,7 +223,7 @@ impl VecVec for &[Vec<f64>] {
     /// let pt = genvec(d,24,7,13); // random test data 5x20
     /// let (_medoideccentricity,medei,_outlierecccentricity,outei) = pt.emedoid();
     /// assert_eq!(medei,19); // index of e-medoid
-    /// assert_eq!(outei,20);  // index of e-outlier
+    /// assert_eq!(outei,4);  // index of e-outlier
     /// ```
     fn emedoid(self) -> (f64, usize, f64, usize) {
         self.eccentricities().mags().minmax()
@@ -233,20 +233,21 @@ impl VecVec for &[Vec<f64>] {
     /// It has (provably) only vector iterative solutions.
     /// Search methods are slow and difficult in highly dimensional space.
     /// Weiszfeld's fixed point iteration formula had known problems with sometimes failing to converge.
-    /// Especially, when the points are dense in the close proximity of the gm, or it coincides with one of them.  
+    /// Especially, when the points are dense in the close proximity of the gm, or gm coincides with one of them.  
     /// However, these problems are fixed in my new algorithm here.      
-    /// There will eventually be a multithreaded version of `nmedian`.
+    /// There will eventually be a multithreaded version.
     fn nmedian(self, eps: f64) -> Vec<f64> {
-        let mut oldpoint = self.acentroid(); // start iterating 
+        let mut point = self.acentroid(); // start iterating 
         loop {
-            let movev = self.eccnonmember(&oldpoint);
-            oldpoint = oldpoint.vadd(&movev);
-            if movev.vmag() < eps { return oldpoint } // make the last small step anyway    
+            let e = self.eccnonmember(&point);
+            point.mutvadd(&e);
+            if e.vmag() < eps { return point } // make the last small step anyway
         } 
     }
-
-    /// First iteration point for geometric medians.
+ 
+    /// Possible first iteration point for geometric medians.
     /// Same as eccnonmember(origin), just saving the zero subtractions
+    /// when moving from the origin
     fn firstpoint(self) -> Vec<f64> {
         let mut rsum = 0_f64;
         let mut vsum = vec![0_f64; self[0].len()];
@@ -260,48 +261,28 @@ impl VecVec for &[Vec<f64>] {
         }
         vsum.smult(1.0/rsum) // scale by the sum of reciprocals
     }
- 
-    /// Iterative two point method for finding the geometric median
-    /// without reciprocal scaling
-    fn gmedian(self, eps: f64) -> Vec<f64> {
-        let mut p1 = self.acentroid();
-        let mut p2 = self.firstpoint();
-        loop {
-            let u = self.eccnonmember(&p1).vunit(); // eccentricity unit vectors
-            let v = self.eccnonmember(&p2).vunit(); // for both points
-            let uv = u.dotp(&v);
-            let pd = p2.vsub(&p1);
-            let udotpd = u.dotp(&pd);
-            let b = (uv*udotpd-v.dotp(&pd))/(1.0-uv.powi(2));
-            let a = udotpd+b*uv;
-            let f1 = p1.vadd(&u.smult(a)); // parmetric vector equations 
-            let f2 = p2.vadd(&v.smult(b)); // for the new points
-            if f1.vdist(&f2).sqrt() < eps {    // termination condition, points are close 
-                return f1.vadd(&f2).smult(0.5)                 // return their midpoint
-            }
-            p1 = f1;
-            p2 = f2;
-        }
-    }
 
     /// Secant method with recovery from divergence
     /// for finding the geometric median
-    fn smedian(self, eps: f64) -> Vec<f64> {
-        // let np = self.len() as f64;
+    fn gmedian(self, eps: f64) -> Vec<f64> {
         let mut p1 = self.acentroid();     
         let e1 = self.eccnonmember(&p1); // eccentricity vector1 
         let mut e1mag = e1.vmag(); 
         let mut p2 = p1.vadd(&e1);   
         loop {
             let e2 = self.eccnonmember(&p2); // eccentricity vector2
-            let e2mag = e2.vmag();           
+            let e2mag = e2.vmag(); 
             if e2mag < eps  { return p2 }; 
-            let ed = if e1mag > e2mag { e1mag-e2mag } else { e1mag + e2mag };
-            let scale = p1.vsub(&p2).vmag()/ed; // secant formula
-            let newp = p2.vadd(&e2.smult(scale)); // generate a new point          
+            let newp;         
+            if e1mag > e2mag {  // eccentricity magnitude decreased, good, employ secant
+                newp = p2.vadd(&e2.smult(p1.vsub(&p2).vmag()/(e1mag-e2mag)))                   
+            }
+            else { // probably overshot the minimum, go nearer, back 
+               newp = p2.vadd(&e2.smult(p1.vsub(&p2).vmag()/(e1mag+e2mag)))                    
+            } 
             p1 = p2;        
             p2 = newp;  
-            e1mag = e2mag;         
+            e1mag = e2mag             
         }       
     }    
 
